#ifndef PQXX_CONFIG_COMPILER_H
#define PQXX_CONFIG_COMPILER_H

/* #undef PQXX_HAVE_ASSUME */
#define PQXX_HAVE_CHARCONV_FLOAT
#define PQXX_HAVE_CXA_DEMANGLE
#define PQXX_HAVE_GCC_PURE
#define PQXX_HAVE_GCC_VISIBILITY
/* #undef PQXX_HAVE_MULTIDIM */
#define PQXX_HAVE_POLL
#define PQXX_HAVE_RANGES
#define PQXX_HAVE_SLEEP_FOR
/* #undef PQXX_HAVE_STACKTRACE */
#define PQXX_HAVE_STRERROR_R
/* #undef PQXX_HAVE_STRERROR_S */
/* #undef PQXX_HAVE_TYPE_DISPLAY */
#define PQXX_HAVE_YEAR_MONTH_DAY
/* #undef PQXX_HAVE_ZARGS */
#endif
